@@ -8,7 +8,7 @@ with 'Dist::Zilla::Role::PluginBundle::Easy',
 use namespace::clean;
 use Data::Section -setup;
 
-our $VERSION = '0.027';
+our $VERSION = '0.028';
 
 sub configure {
 	my $self = shift;
@@ -41,10 +41,10 @@ sub configure {
 	# @Git and versioning
 	$self->add_plugins(
 		'CheckChangesHasContent',
-		['Git::Check' => { allow_dirty => [@dirty_files, @from_build] }],
+		['Git::Check' => { allow_dirty => \@dirty_files }],
 		'RewriteVersion',
 		[NextRelease => { format => '%-9v %{yyyy-MM-dd HH:mm:ss VVV}d%{ (TRIAL RELEASE)}T' }],
-		['Git::Commit' => { allow_dirty => [@dirty_files, @from_build], allow_dirty_match => $versioned_match, add_files_in => '/' }],
+		['Git::Commit' => { allow_dirty => \@dirty_files, allow_dirty_match => $versioned_match, add_files_in => '/' }],
 		'Git::Tag',
 		[BumpVersionAfterRelease => { munge_makefile_pl => 0 }],
 		['Git::Commit' => 'Commit_Version_Bump' => { allow_dirty_match => $versioned_match, commit_msg => 'Bump version' }],
@@ -125,11 +125,6 @@ This is the plugin bundle that DBOOK uses. It is equivalent to:
  allow_dirty = dist.ini
  allow_dirty = Changes
  allow_dirty = README.pod
- allow_dirty = INSTALL
- allow_dirty = LICENSE
- allow_dirty = CONTRIBUTING.md
- allow_dirty = META.json
- allow_dirty = Makefile.PL
  [RewriteVersion]
  [NextRelease]
  format = %-9v %{yyyy-MM-dd HH:mm:ss VVV}d%{ (TRIAL RELEASE)}T
@@ -139,11 +134,6 @@ This is the plugin bundle that DBOOK uses. It is equivalent to:
  allow_dirty = dist.ini
  allow_dirty = Changes
  allow_dirty = README.pod
- allow_dirty = INSTALL
- allow_dirty = LICENSE
- allow_dirty = CONTRIBUTING.md
- allow_dirty = META.json
- allow_dirty = Makefile.PL
  [Git::Tag]
  [BumpVersionAfterRelease]
  munge_makefile_pl = 0
